@@ -1,15 +1,11 @@
 __title__ = 'datclass'
 __author__ = 'foyoux'
-__version__ = '0.0.30'
+__version__ = '0.1.1'
+
 __all__ = [
     'main',
     'DatClass',
-    'List',
-    'Dict',
-    'Union',
-    'TypedDict',
     'dataclass',
-    'field',
     'is_dataclass',
     'set_debug', 'set_extra',
     'DatGen',
@@ -18,18 +14,13 @@ __all__ = [
 import argparse
 import json
 import os
-from dataclasses import dataclass, is_dataclass, field
+from dataclasses import dataclass, is_dataclass
 from pathlib import Path
-from typing import List, Dict, Union
+from typing import get_origin, get_args
 
 from datclass.gens import DatGen
 from datclass.utils import get_ok_identifier
 
-try:
-    from typing import get_origin, get_args, TypedDict
-except ImportError:
-    from typing_extensions import get_origin, get_args, TypedDict
-
 _DEBUG = False
 _EXTRA = True
 _ORIGINAL_INIT = '__dataclass_init__'
@@ -90,7 +81,6 @@ def main():
     parser.add_argument('-r', '--recursive', help='recursive generate dat class', action='store_true')
     parser.add_argument('-o', '--output', help='output file - *.py')
     parser.add_argument('-d', '--dict', help='generate TypedDict class', action='store_true')
-    parser.add_argument('-i', '--inline', help='use inline model to generate TypedDict type', action='store_true')
     parser.add_argument('file', nargs='?', help='input file - likes-json')
 
     args = parser.parse_args()
@@ -127,10 +117,7 @@ def main():
     datgen = DatGen()
 
     if args.dict:
-        if args.inline:
-            codes = datgen.gen_typed_dict_inline(body, name, recursive).codes
-        else:
-            codes = datgen.gen_typed_dict_class(body, name, recursive).codes
+        codes = datgen.gen_typed_dict(body, name, recursive).codes
     else:
         codes = datgen.gen_datclass(body, name, recursive).codes
 
